using Microsoft.Extensions.Logging;
using MotorPlantContracts.BindingModels;
using MotorPlantContracts.BusinessLogicsContracts;
using MotorPlantView;

namespace MotorPlantView.Forms
{
	public partial class FormMain : Form
	{
		private readonly ILogger _logger;
		private readonly IOrderLogic _orderLogic;
		public FormMain(ILogger<FormMain> logger, IOrderLogic orderLogic)
		{
			InitializeComponent();
			_logger = logger;
			_orderLogic = orderLogic;
		}
		private void FormMain_Load(object sender, EventArgs e)
		{
			LoadData();
		}
		private void LoadData()
		{
			_logger.LogInformation(" ");
			try
			{
				var list = _orderLogic.ReadList(null);

				if (list != null)
				{
					dataGridView.DataSource = list;
					dataGridView.Columns["EngineId"].Visible = false;
					dataGridView.Columns["EngineName"].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
				}

				_logger.LogInformation(" ");
			}
			catch (Exception ex)
			{
				_logger.LogError(ex, "  ");
			}
		}
		private void ToolStripMenuItem_Click(object sender, EventArgs e)
		{
			var service = Program.ServiceProvider?.GetService(typeof(FormComponents));

			if (service is FormComponents form)
			{
				form.ShowDialog();
			}
		}
		private void ToolStripMenuItem_Click(object sender, EventArgs e)
		{
			var service = Program.ServiceProvider?.GetService(typeof(FormEngines));

			if (service is FormEngines form)
			{
				form.ShowDialog();
			}
		}
		private void buttonCreateOrder_Click(object sender, EventArgs e)
		{
			var service = Program.ServiceProvider?.GetService(typeof(FormCreateOrder));
			if (service is FormCreateOrder form)
			{
				form.ShowDialog();
				LoadData();
			}
		}
		private void buttonTakeOrderInWork_Click(object sender, EventArgs e)
		{
			if (dataGridView.SelectedRows.Count == 1)
			{
				int id = Convert.ToInt32(dataGridView.SelectedRows[0].Cells["Id"].Value);
				_logger.LogInformation(" {id}.    ' '", id);
				try
				{
					var operationResult = _orderLogic.TakeOrderInWork(new OrderBindingModel
					{
						Id = id,
					});
					if (!operationResult)
					{
						throw new Exception("  .    .");
					}
					LoadData();
				}
				catch (Exception ex)
				{
					_logger.LogError(ex, "    ");
					MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}
		private void buttonOrderReady_Click(object sender, EventArgs e)
		{
			if (dataGridView.SelectedRows.Count == 1)
			{
				int id =
			   Convert.ToInt32(dataGridView.SelectedRows[0].Cells["Id"].Value);
				_logger.LogInformation(" {id}.    ''", id);
				try
				{
					var operationResult = _orderLogic.FinishOrder(new OrderBindingModel { Id = id });
					if (!operationResult)
					{
						throw new Exception("  .    .");
					}
					LoadData();
				}
				catch (Exception ex)
				{
					_logger.LogError(ex, "    ");
					MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}
		private void buttonIssuedOrder_Click(object sender, EventArgs e)
		{
			if (dataGridView.SelectedRows.Count == 1)
			{
				int id = Convert.ToInt32(dataGridView.SelectedRows[0].Cells["Id"].Value);
				_logger.LogInformation(" {id}.    ''", id);
				try
				{
					var operationResult = _orderLogic.DeliveryOrder(new OrderBindingModel
					{
						Id = id
					});
					if (!operationResult)
					{
						throw new Exception("  .    .");
					}
					_logger.LogInformation(" {id} ", id);
					LoadData();
				}
				catch (Exception ex)
				{
					_logger.LogError(ex, "    "); MessageBox.Show(ex.Message, "", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}
		private void buttonRef_Click(object sender, EventArgs e)
		{
			LoadData();
		}
		private void ShopsToolStripMenuItem_Click(object sender, EventArgs e)
		{
			var service = Program.ServiceProvider?.GetService(typeof(FormShops));

			if (service is FormShops form)
			{
				form.ShowDialog();
			}
		}

		private void SupplyToolStripMenuItem_Click(object sender, EventArgs e)
		{
			var service = Program.ServiceProvider?.GetService(typeof(FormSupply));

			if (service is FormSupply form)
			{
				form.ShowDialog();
			}
		}
	}
}
